import { __awaiter } from "tslib";
import { logger } from '../utils';
/**
 * importPBCAssets.
 *
 * @remarks
 * A utility for importing PBC assets that have been added to the application's src/pbc directory via genx add.
 *
 * @example
 * ```ts
 * import { importPBCAssets } from '@genesislcap/foundation-shell/pbc';
 * ...
 * const assets = await importPBCAssets();
 * ...
 * app.registerAssets(assets);
 * ```
 *
 * @public
 */
export function importPBCAssets() {
    return __awaiter(this, void 0, void 0, function* () {
        let assets;
        if (BUILDER === 'webpack') {
            assets = yield import('./webpack');
        }
        else if (BUILDER === 'vite') {
            assets = yield import('./vite');
        }
        else {
            logger.error('importPBCs error. Unable to determine the builder in use.');
        }
        return assets;
    });
}
